@@ -27,5 +27,9 @@ class AttrStateMixin(TransformMixin, InspectionMixin):
         for k, v in self.get_attr_changes().items():
             # (type_, key, info, col)
             info = inspections[k][2]
-            res[self.export_column_name(k, info)] = v
+            col = inspections[k][3]
+            res[self.export_column_name(k, info)] = (
+                self.export_value(col, v[0]),
+                self.export_value(col, v[1]),
+            )
         return res
